@@ -89,7 +89,8 @@ long long int llroundl(long double x);
 typedef enum {
 	EXTRACT_MIME_AUDIO,
 	EXTRACT_MIME_VIDEO,
-	EXTRACT_MIME_IMAGE
+	EXTRACT_MIME_IMAGE,
+	EXTRACT_MIME_3GPP,
 } ExtractMime;
 
 typedef struct {
@@ -98,20 +99,20 @@ typedef struct {
 
 	GstBus         *bus;
 
-	ExtractMime	mime;
+	ExtractMime     mime;
 
 
 	/* Decodebin elements and properties*/
-	GstElement     *bin;	
+	GstElement     *bin;
 	GList          *fsinks;
 
 	gint64          duration;
-	gint		video_height;
-	gint		video_width;
-	gint		video_fps_n;
-	gint		video_fps_d;
-	gint		audio_channels;
-	gint		audio_samplerate;
+	gint            video_height;
+	gint            video_width;
+	gint            video_fps_n;
+	gint            video_fps_d;
+	gint            audio_channels;
+	gint            audio_samplerate;
 
 	/* Tags and data */
 	GstTagList     *tagcache;
@@ -125,11 +126,14 @@ typedef struct {
 static void extract_gstreamer_audio (const gchar *uri, TrackerSparqlBuilder *metadata);
 static void extract_gstreamer_video (const gchar *uri, TrackerSparqlBuilder *metadata);
 static void extract_gstreamer_image (const gchar *uri, TrackerSparqlBuilder *metadata);
+static void extract_gstreamer_3gpp (const gchar *uri, TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 	{ "audio/*", extract_gstreamer_audio },
 	{ "video/*", extract_gstreamer_video },
 	{ "image/*", extract_gstreamer_image },
+	/* mime type guessing returns video/3gpp also for 3gpp audio files */
+	{ "video/3gpp", extract_gstreamer_3gpp },
 	{ NULL, NULL }
 };
 
@@ -142,30 +146,32 @@ const gboolean use_tagreadbin = FALSE;
 
 static void
 add_int64_info (TrackerSparqlBuilder *metadata,
-		const gchar *uri,
-		const gchar *key,
-		gint64	    info)
+                const gchar *uri,
+                const gchar *key,
+                gint64      info)
 {
-	tracker_statement_list_insert_with_int64 (metadata, uri, key, info);
+	tracker_sparql_builder_predicate (metadata, key);
+	tracker_sparql_builder_object_int64 (metadata, info);
 }
 
 static void
 add_uint_info (TrackerSparqlBuilder *metadata,
-	       const gchar *uri,
-	       const gchar *key,
-	       guint	   info)
+               const gchar *uri,
+               const gchar *key,
+               guint       info)
 {
-	tracker_statement_list_insert_with_int (metadata, uri, key, info);
+	tracker_sparql_builder_predicate (metadata, key);
+	tracker_sparql_builder_object_int64 (metadata, info);
 }
 
 static void
-add_string_gst_tag (TrackerSparqlBuilder	*metadata,
-		    const gchar *uri,
-		    const gchar *key,
-		    GstTagList	*tag_list,
-		    const gchar *tag)
+add_string_gst_tag (TrackerSparqlBuilder *metadata,
+                    const gchar          *uri,
+                    const gchar          *key,
+                    GstTagList           *tag_list,
+                    const gchar          *tag)
 {
-	gchar	 *s;
+	gchar    *s;
 	gboolean  ret;
 
 	s = NULL;
@@ -173,7 +179,8 @@ add_string_gst_tag (TrackerSparqlBuilder	*metadata,
 
 	if (s) {
 		if (ret && s[0] != '\0') {
-			tracker_statement_list_insert (metadata, uri, key, s);
+			tracker_sparql_builder_predicate (metadata, key);
+			tracker_sparql_builder_object_unvalidated (metadata, s);
 		}
 
 		g_free (s);
@@ -182,64 +189,67 @@ add_string_gst_tag (TrackerSparqlBuilder	*metadata,
 
 static void
 add_uint_gst_tag (TrackerSparqlBuilder   *metadata,
-		  const gchar *uri,
-		  const gchar *key,
-		  GstTagList  *tag_list,
-		  const gchar *tag)
+                  const gchar *uri,
+                  const gchar *key,
+                  GstTagList  *tag_list,
+                  const gchar *tag)
 {
 	gboolean ret;
-	guint	 n;
+	guint    n;
 
 	ret = gst_tag_list_get_uint (tag_list, tag, &n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_int (metadata, uri, key, n);
+		tracker_sparql_builder_predicate (metadata, key);
+		tracker_sparql_builder_object_int64 (metadata, n);
 	}
 }
 
 static void
 add_int_gst_tag (TrackerSparqlBuilder   *metadata,
-		 const gchar *uri,
-		 const gchar *key,
-		 GstTagList  *tag_list,
-		 const gchar *tag)
+                 const gchar *uri,
+                 const gchar *key,
+                 GstTagList  *tag_list,
+                 const gchar *tag)
 {
 	gboolean ret;
-	gint	 n;
+	gint     n;
 
 	ret = gst_tag_list_get_int (tag_list, tag, &n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_int (metadata, uri, key, n);	
+		tracker_sparql_builder_predicate (metadata, key);
+		tracker_sparql_builder_object_int64 (metadata, n);
 	}
 }
 
 static void
-add_double_gst_tag (TrackerSparqlBuilder	*metadata,
-		    const gchar *uri,
-		    const gchar *key,
-		    GstTagList	*tag_list,
-		    const gchar *tag)
+add_double_gst_tag (TrackerSparqlBuilder        *metadata,
+                    const gchar *uri,
+                    const gchar *key,
+                    GstTagList  *tag_list,
+                    const gchar *tag)
 {
 	gboolean ret;
-	gdouble	 n;
+	gdouble          n;
 
 	ret = gst_tag_list_get_double (tag_list, tag, &n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_double (metadata, uri, key, n);
+		tracker_sparql_builder_predicate (metadata, key);
+		tracker_sparql_builder_object_int64 (metadata, (gint64) n);
 	}
 }
 
 static void
 add_fraction_gst_tag (TrackerSparqlBuilder         *metadata,
-		      const gchar       *uri,
-		      const gchar       *key,
-		      GstTagList	*tag_list,
-		      const gchar       *tag)
+                      const gchar       *uri,
+                      const gchar       *key,
+                      GstTagList        *tag_list,
+                      const gchar       *tag)
 {
 	gboolean ret;
-	GValue	 n = {0,};
+	GValue   n = {0,};
 	gfloat   f;
 
 	ret = gst_tag_list_copy_value (&n, tag_list, tag);
@@ -248,18 +258,19 @@ add_fraction_gst_tag (TrackerSparqlBuilder         *metadata,
 		gst_value_get_fraction_denominator (&n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_float (metadata, uri, key, f);
+		tracker_sparql_builder_predicate (metadata, key);
+		tracker_sparql_builder_object_double (metadata, (gdouble) f);
 	}
 }
 
 static void
 add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
-		    const gchar *uri,
-		    const gchar *key,
-		    GstTagList  *tag_list,
-		    const gchar *tag)
+                    const gchar *uri,
+                    const gchar *key,
+                    GstTagList  *tag_list,
+                    const gchar *tag)
 {
-	GDate	 *date;
+	GDate    *date;
 	gboolean  ret;
 
 	date = NULL;
@@ -269,8 +280,8 @@ add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
 		gchar buf[10];
 
 		if (g_date_strftime (buf, 10, "%Y", date)) {
-			tracker_statement_list_insert (metadata, uri,
-						       key, buf);
+			tracker_sparql_builder_predicate (metadata, key);
+			tracker_sparql_builder_object_unvalidated (metadata, buf);
 		}
 	}
 
@@ -281,20 +292,23 @@ add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
 
 static void
 add_time_gst_tag (TrackerSparqlBuilder   *metadata,
-		  const gchar *uri,
-		  const gchar *key,
-		  GstTagList  *tag_list,
-		  const gchar *tag)
+                  const gchar *uri,
+                  const gchar *key,
+                  GstTagList  *tag_list,
+                  const gchar *tag)
 {
 	gboolean ret;
-	guint64	 n;
+	guint64          n;
 
 	ret = gst_tag_list_get_uint64 (tag_list, tag, &n);
 
 	if (ret) {
-		gchar *str = g_strdup_printf ("%lld", llroundl ((long double)n/(long double)GST_SECOND));
-		tracker_statement_list_insert (metadata, uri, key, str);
-		g_free (str);
+		gint64 duration;
+
+		duration = llroundl ((long double) n / (long double) GST_SECOND);
+
+		tracker_sparql_builder_predicate (metadata, key);
+		tracker_sparql_builder_object_int64 (metadata, duration);
 	}
 }
 
@@ -320,9 +334,9 @@ get_embedded_album_art(MetadataExtractor *extractor)
 			caps_struct = gst_caps_get_structure (buffer->caps, 0);
 
 			gst_structure_get_enum (caps_struct,
-						"image-type",
-						GST_TYPE_TAG_IMAGE_TYPE,
-						&type);
+			                        "image-type",
+			                        GST_TYPE_TAG_IMAGE_TYPE,
+			                        &type);
 
 			if ((type == GST_TAG_IMAGE_TYPE_FRONT_COVER)||
 			    ((type == GST_TAG_IMAGE_TYPE_UNDEFINED)&&(extractor->album_art_size == 0))) {
@@ -364,73 +378,66 @@ get_embedded_album_art(MetadataExtractor *extractor)
 
 static void
 extract_stream_metadata_tagreadbin (MetadataExtractor *extractor,
-				    const gchar       *uri,
-				    TrackerSparqlBuilder         *metadata)
+                                    const gchar       *uri,
+                                    TrackerSparqlBuilder         *metadata)
 {
 	if (extractor->mime != EXTRACT_MIME_IMAGE) {
-		add_uint_gst_tag (metadata, uri, NFO_PREFIX "channels", extractor->tagcache, GST_TAG_CHANNEL);
-		add_uint_gst_tag (metadata, uri, NFO_PREFIX "sampleRate", extractor->tagcache, GST_TAG_RATE);
-		add_time_gst_tag (metadata, uri, NFO_PREFIX "duration", extractor->tagcache, GST_TAG_DURATION); 
+		add_uint_gst_tag (metadata, uri, "nfo:channels", extractor->tagcache, GST_TAG_CHANNEL);
+		add_uint_gst_tag (metadata, uri, "nfo:sampleRate", extractor->tagcache, GST_TAG_RATE);
+		add_time_gst_tag (metadata, uri, "nfo:duration", extractor->tagcache, GST_TAG_DURATION);
 	}
 
-	add_int_gst_tag (metadata, uri, NFO_PREFIX "height", extractor->tagcache, GST_TAG_HEIGHT);
-	add_int_gst_tag (metadata, uri, NFO_PREFIX "width", extractor->tagcache, GST_TAG_WIDTH);
+	add_int_gst_tag (metadata, uri, "nfo:height", extractor->tagcache, GST_TAG_HEIGHT);
+	add_int_gst_tag (metadata, uri, "nfo:width", extractor->tagcache, GST_TAG_WIDTH);
 
 	if (extractor->mime == EXTRACT_MIME_VIDEO) {
-		add_fraction_gst_tag   (metadata, uri, NFO_PREFIX "frameRate", extractor->tagcache, GST_TAG_FRAMERATE);	
+		add_fraction_gst_tag (metadata, uri, "nfo:frameRate", extractor->tagcache, GST_TAG_FRAMERATE);
 	}
 }
 
 static void
 extract_stream_metadata_decodebin (MetadataExtractor *extractor,
-				   const gchar       *uri,
-				   TrackerSparqlBuilder         *metadata)
+                                   const gchar       *uri,
+                                   TrackerSparqlBuilder         *metadata)
 {
 	if (extractor->mime != EXTRACT_MIME_IMAGE) {
 		if (extractor->audio_channels >= 0) {
-			add_uint_info (metadata,
-				       uri, NFO_PREFIX "channels",
-				       extractor->audio_channels);
+			add_uint_info (metadata, uri, "nfo:channels", extractor->audio_channels);
 		}
 
 		if (extractor->audio_samplerate >= 0) {
-			add_uint_info (metadata,
-				       uri, NFO_PREFIX "sampleRate",
-				       extractor->audio_samplerate);
+			add_uint_info (metadata, uri, "nfo:sampleRate", extractor->audio_samplerate);
 		}
 
 		if (extractor->duration >= 0) {
-			add_int64_info (metadata, uri, NFO_PREFIX "duration", extractor->duration);
+			add_int64_info (metadata, uri, "nfo:duration", extractor->duration);
 		}
 	}
 
 	if (extractor->video_height >= 0) {
-		add_uint_info (metadata,
-			       uri, NFO_PREFIX "height",
-			       extractor->video_height);
+		add_uint_info (metadata, uri, "nfo:height", extractor->video_height);
 	}
 
 	if (extractor->video_width >= 0) {
-		add_uint_info (metadata,
-			       uri, NFO_PREFIX "width",
-			       extractor->video_width);
+		add_uint_info (metadata, uri, "nfo:width", extractor->video_width);
 	}
 
 	if (extractor->mime == EXTRACT_MIME_VIDEO) {
 		if (extractor->video_fps_n >= 0 && extractor->video_fps_d >= 0) {
 			add_uint_info (metadata,
-				       uri, NFO_PREFIX "frameRate",
-				       ((extractor->video_fps_n + extractor->video_fps_d / 2) / 
-					extractor->video_fps_d));
+			               uri, "nfo:frameRate",
+			               ((extractor->video_fps_n + extractor->video_fps_d / 2) /
+			                extractor->video_fps_d));
 		}
 	}
 }
 
 static void
-extract_metadata (MetadataExtractor *extractor,
-		  const gchar       *uri,
-		  TrackerSparqlBuilder         *metadata,
-		  gchar **album, gchar **scount)
+extract_metadata (MetadataExtractor      *extractor,
+                  const gchar            *uri,
+                  TrackerSparqlBuilder   *metadata,
+                  gchar                 **album,
+                  gchar                 **scount)
 {
 	gchar *s;
 	gboolean ret;
@@ -440,47 +447,24 @@ extract_metadata (MetadataExtractor *extractor,
 	g_return_if_fail (metadata != NULL);
 
 	if (extractor->tagcache) {
+		if (extractor->mime == EXTRACT_MIME_3GPP) {
+			gchar *video_codec = NULL, *audio_codec = NULL;
+
+			gst_tag_list_get_string (extractor->tagcache, GST_TAG_VIDEO_CODEC, &video_codec);
+			gst_tag_list_get_string (extractor->tagcache, GST_TAG_AUDIO_CODEC, &audio_codec);
+
+			if (audio_codec && !video_codec) {
+				extractor->mime = EXTRACT_MIME_AUDIO;
+			} else {
+				/* default to video */
+				extractor->mime = EXTRACT_MIME_VIDEO;
+			}
+
+			g_free (video_codec);
+			g_free (audio_codec);
+		}
+
 		/* General */
-
-		add_string_gst_tag (metadata, uri, NIE_PREFIX "title", extractor->tagcache, GST_TAG_TITLE);
-		add_string_gst_tag (metadata, uri, NIE_PREFIX "copyright", extractor->tagcache, GST_TAG_COPYRIGHT);
-		add_string_gst_tag (metadata, uri, NIE_PREFIX "license", extractor->tagcache, GST_TAG_LICENSE);
-		add_string_gst_tag (metadata, uri, DC_PREFIX "coverage", extractor->tagcache, GST_TAG_LOCATION);
-		add_y_date_gst_tag (metadata, uri, NIE_PREFIX "contentCreated", extractor->tagcache, GST_TAG_DATE);
-		add_string_gst_tag (metadata, uri, NIE_PREFIX "comment", extractor->tagcache, GST_TAG_COMMENT);
-
-		if (extractor->mime == EXTRACT_MIME_VIDEO) {
-			add_string_gst_tag (metadata, uri, DC_PREFIX "source", extractor->tagcache, GST_TAG_CLASSIFICATION);
-		}
-
-		if (extractor->mime == EXTRACT_MIME_AUDIO) {
-			/* Audio */
-			s = NULL;
-			gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
-			if (s) {
-				gchar *canonical_uri = tracker_uri_printf_escaped ("urn:album:%s", s);
-				tracker_statement_list_insert (metadata, canonical_uri, RDF_TYPE, NMM_PREFIX "MusicAlbum");
-				tracker_statement_list_insert (metadata, canonical_uri, NMM_PREFIX "albumTitle", s);
-				tracker_statement_list_insert (metadata, uri, NMM_PREFIX "musicAlbum", canonical_uri);
-				add_uint_gst_tag (metadata, canonical_uri, NMM_PREFIX "albumTrackCount", extractor->tagcache, GST_TAG_TRACK_COUNT);
-				g_free (canonical_uri);
-				*album = s;
-			}
-
-			ret = gst_tag_list_get_uint (extractor->tagcache, GST_TAG_TRACK_COUNT, &count);
-			if (ret) {
-				*scount = g_strdup_printf ("%d", count);
-			}
-
-			add_uint_gst_tag   (metadata, uri, NMM_PREFIX "trackNumber", extractor->tagcache, GST_TAG_TRACK_NUMBER);
-			add_uint_gst_tag   (metadata, uri, NMM_PREFIX "setNumber", extractor->tagcache, GST_TAG_ALBUM_VOLUME_NUMBER);
-
-			add_double_gst_tag (metadata, uri, NFO_PREFIX "gain", extractor->tagcache, GST_TAG_TRACK_GAIN);
-			add_double_gst_tag (metadata, uri, NFO_PREFIX "peakGain", extractor->tagcache, GST_TAG_TRACK_PEAK);
-			add_double_gst_tag (metadata, uri, NFO_PREFIX "albumGain", extractor->tagcache, GST_TAG_ALBUM_GAIN);
-			add_double_gst_tag (metadata, uri, NFO_PREFIX "albumPeakGain", extractor->tagcache, GST_TAG_ALBUM_PEAK);
-		}
-
 		if (extractor->mime == EXTRACT_MIME_AUDIO || extractor->mime == EXTRACT_MIME_VIDEO) {
 			gchar *performer = NULL, *artist = NULL;
 
@@ -491,42 +475,118 @@ extract_metadata (MetadataExtractor *extractor,
 
 			if (s) {
 				gchar *canonical_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
-				tracker_statement_list_insert (metadata, canonical_uri, RDF_TYPE, NMM_PREFIX "Artist");
-				tracker_statement_list_insert (metadata, canonical_uri, NMM_PREFIX "artistName", s);
-				tracker_statement_list_insert (metadata, uri, 
-							       (extractor->mime == EXTRACT_MIME_AUDIO ? 
-							        NMM_PREFIX "performer" :
-							        NMM_PREFIX "leadActor"),
-							       canonical_uri);
+
+				tracker_sparql_builder_subject_iri (metadata, canonical_uri);
+				tracker_sparql_builder_predicate (metadata, "a");
+				tracker_sparql_builder_object (metadata, "nmm:Artist");
+				/*
+				if (extractor->mime == EXTRACT_MIME_AUDIO) {
+					tracker_sparql_builder_object (metadata, "nmm:performer");
+				} else {
+					tracker_sparql_builder_object (metadata, "nmm:leadActor");
+				}
+				*/
+				tracker_sparql_builder_predicate (metadata, "nmm:artistName");
+				tracker_sparql_builder_object_unvalidated (metadata, s);
+
 				g_free (canonical_uri);
 				g_free (s);
 			}
 
 			s = NULL;
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_COMPOSER, &s);
+
 			if (s) {
 				gchar *canonical_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
-				tracker_statement_list_insert (metadata, canonical_uri, RDF_TYPE, NMM_PREFIX "Artist");
-				tracker_statement_list_insert (metadata, canonical_uri, NMM_PREFIX "artistName", s);
-				tracker_statement_list_insert (metadata, uri, 
-							       (extractor->mime == EXTRACT_MIME_AUDIO ? 
-							        NMM_PREFIX "composer" :
-							        NMM_PREFIX "director"),
-							       canonical_uri);
+
+				tracker_sparql_builder_subject_iri (metadata, canonical_uri);
+				tracker_sparql_builder_predicate (metadata, "a");
+				tracker_sparql_builder_object (metadata, "nmm:Artist");
+
+				/*
+				if (extractor->mime == EXTRACT_MIME_AUDIO) {
+					tracker_sparql_builder_object (metadata, "nmm:composer");
+				} else {
+					tracker_sparql_builder_object (metadata, "nmm:director");
+				}
+				*/
+				tracker_sparql_builder_predicate (metadata, "nmm:artistName");
+				tracker_sparql_builder_object_unvalidated (metadata, s);
+
 				g_free (canonical_uri);
 				g_free (s);
 			}
 
-			s = NULL;
-			gst_tag_list_get_string (extractor->tagcache, GST_TAG_GENRE, &s);
-			if (s && strcmp (s, "Unknown") != 0) {
-				tracker_statement_list_insert (metadata, uri, NFO_PREFIX "genre", s);
-			}
-			g_free (s);
-
-			add_string_gst_tag (metadata, uri, NFO_PREFIX "codec", extractor->tagcache, GST_TAG_AUDIO_CODEC);
-
 		}
+
+		if (extractor->mime == EXTRACT_MIME_AUDIO) {
+			/* Audio */
+			s = NULL;
+			gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
+			if (s) {
+				gchar *urn;
+
+				urn = tracker_uri_printf_escaped ("urn:album:%s", s);
+				tracker_sparql_builder_subject_iri (metadata, urn);
+				tracker_sparql_builder_predicate (metadata, "a");
+				tracker_sparql_builder_object (metadata, "nmm:MusicAlbum");
+				tracker_sparql_builder_predicate (metadata, "nmm:albumTitle");
+				tracker_sparql_builder_object_unvalidated (metadata, s);
+				add_uint_gst_tag (metadata, urn, "nmm:albumTrackCount", extractor->tagcache, GST_TAG_TRACK_COUNT);
+				add_uint_gst_tag (metadata, urn, "nmm:setNumber", extractor->tagcache, GST_TAG_ALBUM_VOLUME_NUMBER);
+				*album = s;
+
+				g_free (urn);
+			}
+		}
+
+		tracker_sparql_builder_subject_iri (metadata, uri);
+		tracker_sparql_builder_predicate (metadata, "a");
+
+		if (extractor->mime == EXTRACT_MIME_AUDIO) {
+			tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
+			tracker_sparql_builder_object (metadata, "nfo:Audio");
+		} else if (extractor->mime == EXTRACT_MIME_VIDEO) {
+			tracker_sparql_builder_object (metadata, "nmm:Video");
+		} else {
+			tracker_sparql_builder_object (metadata, "nfo:Image");
+		}
+
+		s = NULL;
+		gst_tag_list_get_string (extractor->tagcache, GST_TAG_GENRE, &s);
+		if (s && strcmp (s, "Unknown") != 0) {
+			tracker_sparql_builder_predicate (metadata, "nfo:genre");
+			tracker_sparql_builder_object_unvalidated (metadata, s);
+		}
+		g_free (s);
+
+		add_string_gst_tag (metadata, uri, "nie:title", extractor->tagcache, GST_TAG_TITLE);
+		add_string_gst_tag (metadata, uri, "nie:copyright", extractor->tagcache, GST_TAG_COPYRIGHT);
+		add_string_gst_tag (metadata, uri, "nie:license", extractor->tagcache, GST_TAG_LICENSE);
+		add_string_gst_tag (metadata, uri, "dc:coverage", extractor->tagcache, GST_TAG_LOCATION);
+		add_y_date_gst_tag (metadata, uri, "nie:contentCreated", extractor->tagcache, GST_TAG_DATE);
+		add_string_gst_tag (metadata, uri, "nie:comment", extractor->tagcache, GST_TAG_COMMENT);
+
+		if (extractor->mime == EXTRACT_MIME_VIDEO) {
+			add_string_gst_tag (metadata, uri, "dc:source", extractor->tagcache, GST_TAG_CLASSIFICATION);
+		}
+
+		if (extractor->mime == EXTRACT_MIME_AUDIO) {
+			/* Audio */
+			ret = gst_tag_list_get_uint (extractor->tagcache, GST_TAG_TRACK_COUNT, &count);
+			if (ret) {
+				*scount = g_strdup_printf ("%d", count);
+			}
+
+			add_uint_gst_tag   (metadata, uri, "nmm:trackNumber", extractor->tagcache, GST_TAG_TRACK_NUMBER);
+
+			add_double_gst_tag (metadata, uri, "nfo:gain", extractor->tagcache, GST_TAG_TRACK_GAIN);
+			add_double_gst_tag (metadata, uri, "nfo:peakGain", extractor->tagcache, GST_TAG_TRACK_PEAK);
+			add_double_gst_tag (metadata, uri, "nfo:albumGain", extractor->tagcache, GST_TAG_ALBUM_GAIN);
+			add_double_gst_tag (metadata, uri, "nfo:albumPeakGain", extractor->tagcache, GST_TAG_ALBUM_PEAK);
+		}
+
+		add_string_gst_tag (metadata, uri, "nfo:codec", extractor->tagcache, GST_TAG_AUDIO_CODEC);
 	}
 
 	if (use_tagreadbin) {
@@ -560,16 +620,16 @@ dbin_dpad_cb (GstElement* e, GstPad* pad, gboolean cont, gpointer data_)
 	GValue             val = {0, };
 
 	fsink = gst_element_factory_make ("fakesink", NULL);
-	
+
 	/* We increase the preroll buffer so we get duration (one frame not enough)*/
 	g_value_init (&val, G_TYPE_INT);
-	g_value_set_int (&val, 51); 
+	g_value_set_int (&val, 51);
 	g_object_set_property (G_OBJECT (fsink), "preroll-queue-len", &val);
 	g_value_unset (&val);
 
 	extractor->fsinks = g_list_append (extractor->fsinks, fsink);
 	gst_element_set_state (fsink, GST_STATE_PAUSED);
-	
+
 	gst_bin_add (GST_BIN (extractor->pipeline), fsink);
 	fsinkpad = gst_element_get_static_pad (fsink, "sink");
 	gst_pad_link (pad, fsinkpad);
@@ -579,7 +639,7 @@ dbin_dpad_cb (GstElement* e, GstPad* pad, gboolean cont, gpointer data_)
 static guint64
 get_media_duration (MetadataExtractor *extractor)
 {
-	gint64	  duration;
+	gint64    duration;
 	GstFormat fmt;
 
 	g_return_val_if_fail (extractor, -1);
@@ -588,10 +648,10 @@ get_media_duration (MetadataExtractor *extractor)
 	fmt = GST_FORMAT_TIME;
 
 	duration = -1;
-	
+
 	if (gst_element_query_duration (extractor->pipeline,
-					&fmt,
-					&duration) &&
+	                                &fmt,
+	                                &duration) &&
 	    duration >= 0) {
 		return duration / GST_SECOND;
 	} else {
@@ -606,21 +666,21 @@ add_stream_tag (void *obj, void *data_)
 	GstElement        *fsink     = (GstElement *) obj;
 
 	GstStructure      *s         = NULL;
-	GstCaps	          *caps      = NULL;
+	GstCaps                   *caps      = NULL;
 
 	if ((caps = GST_PAD_CAPS (fsink))) {
 		s = gst_caps_get_structure (caps, 0);
-		
+
 		if (s) {
 			if (g_strrstr (gst_structure_get_name (s), "audio")) {
 				if ( ( (extractor->audio_channels != -1) &&
 				       (extractor->audio_samplerate != -1) ) ||
 				     !( (gst_structure_get_int (s,
-								"channels",
-								&extractor->audio_channels) ) &&
-					(gst_structure_get_int (s,
-								"rate",
-								&extractor->audio_samplerate)) ) ) {
+				                                "channels",
+				                                &extractor->audio_channels) ) &&
+				        (gst_structure_get_int (s,
+				                                "rate",
+				                                &extractor->audio_samplerate)) ) ) {
 					return;
 				}
 			} else if (g_strrstr (gst_structure_get_name (s), "video")) {
@@ -629,11 +689,11 @@ add_stream_tag (void *obj, void *data_)
 				       (extractor->video_width != -1) &&
 				       (extractor->video_height != -1) ) ||
 				     !( (gst_structure_get_fraction (s,
-								     "framerate",
-								     &extractor->video_fps_n,
-								     &extractor->video_fps_d) ) &&
-					(gst_structure_get_int (s, "width", &extractor->video_width)) &&
-					(gst_structure_get_int (s, "height", &extractor->video_height)))) {
+				                                     "framerate",
+				                                     &extractor->video_fps_n,
+				                                     &extractor->video_fps_d) ) &&
+				        (gst_structure_get_int (s, "width", &extractor->video_width)) &&
+				        (gst_structure_get_int (s, "height", &extractor->video_height)))) {
 					return;
 				}
 			}
@@ -654,8 +714,8 @@ add_tags (GstTagList *new_tags, MetadataExtractor *extractor)
 	GstTagList   *result;
 
 	result = gst_tag_list_merge (extractor->tagcache,
-				     new_tags,
-				     GST_TAG_MERGE_KEEP);
+	                             new_tags,
+	                             GST_TAG_MERGE_KEEP);
 
 	if (extractor->tagcache) {
 		gst_tag_list_free (extractor->tagcache);
@@ -667,9 +727,9 @@ add_tags (GstTagList *new_tags, MetadataExtractor *extractor)
 
 static gboolean
 poll_for_ready (MetadataExtractor *extractor,
-		GstState state,
-		gboolean ready_with_state,
-		gboolean ready_with_eos)
+                GstState state,
+                gboolean ready_with_state,
+                gboolean ready_with_eos)
 {
 	gint64              timeout   = 5 * GST_SECOND;
 	GstBus             *bus       = extractor->bus;
@@ -680,21 +740,21 @@ poll_for_ready (MetadataExtractor *extractor,
 	while (TRUE) {
 		GstMessage *message;
 		GstElement *src;
-		
+
 		message = gst_bus_timed_pop (bus, timeout);
-		
+
 		if (!message) {
 			g_warning ("Pipeline timed out");
 			return FALSE;
 		}
-		
+
 		src = (GstElement*)GST_MESSAGE_SRC (message);
-		
+
 		switch (GST_MESSAGE_TYPE (message)) {
 		case GST_MESSAGE_STATE_CHANGED: {
 			if (ready_with_state) {
 				GstState old, new, pending;
-				
+
 				if (src == extractor->pipeline) {
 					gst_message_parse_state_changed (message, &old, &new, &pending);
 					if (new == state) {
@@ -739,12 +799,12 @@ poll_for_ready (MetadataExtractor *extractor,
 			/* Nothing to do here */
 			break;
 		}
-		
+
 		gst_message_unref (message);
 	}
-	
+
 	g_assert_not_reached ();
-	
+
 	return FALSE;
 }
 
@@ -752,7 +812,7 @@ static GstElement *
 create_decodebin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 {
 	GstElement *pipeline = NULL;
-	
+
 	GstElement *filesrc  = NULL;
 	GstElement *bin      = NULL;
 
@@ -776,11 +836,11 @@ create_decodebin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 		return FALSE;
 	}
 
-	id = g_signal_connect (G_OBJECT (bin), 
-			       "new-decoded-pad",
-			       G_CALLBACK (dbin_dpad_cb), 
-			       extractor);
-	
+	id = g_signal_connect (G_OBJECT (bin),
+	                       "new-decoded-pad",
+	                       G_CALLBACK (dbin_dpad_cb),
+	                       extractor);
+
 	gst_bin_add (GST_BIN (pipeline), filesrc);
 	gst_bin_add (GST_BIN (pipeline), bin);
 
@@ -800,7 +860,6 @@ static GstElement *
 create_tagreadbin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 {
 	GstElement *pipeline = NULL;
-	gchar      *complete_uri = NULL;
 
 	pipeline = gst_element_factory_make ("tagreadbin", "tagreadbin");
 	if (!pipeline) {
@@ -808,22 +867,15 @@ create_tagreadbin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 		return NULL;
 	}
 
-	complete_uri = g_filename_to_uri (uri, NULL, NULL);
-	if (!complete_uri) {
-		g_warning ("Failed to convert filename to uri");
-		return NULL;
-	}
-
-	g_object_set (G_OBJECT (pipeline), "uri", complete_uri, NULL);
-	g_free (complete_uri);
+	g_object_set (G_OBJECT (pipeline), "uri", uri, NULL);
 	return pipeline;
 }
 
 
 static void
 tracker_extract_gstreamer (const gchar *uri,
-			   TrackerSparqlBuilder  *metadata,
-			   ExtractMime	type)
+                           TrackerSparqlBuilder  *metadata,
+                           ExtractMime  type)
 {
 	MetadataExtractor *extractor;
 	gchar *album, *scount;
@@ -843,7 +895,7 @@ tracker_extract_gstreamer (const gchar *uri,
 	extractor->mime         = type;
 
 	extractor->tagcache     = NULL;
-	
+
 	extractor->album_art_data = NULL;
 	extractor->album_art_size = 0;
 	extractor->album_art_mime = NULL;
@@ -874,7 +926,7 @@ tracker_extract_gstreamer (const gchar *uri,
 		if (!poll_for_ready (extractor, GST_STATE_PLAYING, FALSE, TRUE)) {
 			g_warning ("Error running tagreadbin");
 			return;
-		}			
+		}
 	} else {
 		if (!poll_for_ready (extractor, GST_STATE_PAUSED, TRUE, FALSE)) {
 			g_warning ("Error running decodebin");
@@ -894,25 +946,12 @@ tracker_extract_gstreamer (const gchar *uri,
 
 	extract_metadata (extractor, uri, metadata, &album, &scount);
 
-	/* Save embedded art */
-	if (extractor->album_art_data && extractor->album_art_size) {
-#ifdef HAVE_GDKPIXBUF
-		tracker_albumart_process (extractor->album_art_data, 
-					  extractor->album_art_size, 
-					  extractor->album_art_mime,
-					  /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
-					  album,
-					  uri);
-#else
-		tracker_albumart_process (NULL,
-					  0, 
-					  NULL,
-					  /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
-					  album,
-					  uri);
-		
-#endif /* HAVE_GDKPIXBUF */
-	}
+	tracker_albumart_process (extractor->album_art_data,
+	                          extractor->album_art_size,
+	                          extractor->album_art_mime,
+	                          /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
+	                          album,
+	                          uri);
 
 	g_free (scount);
 	g_free (album);
@@ -933,37 +972,27 @@ tracker_extract_gstreamer (const gchar *uri,
 static void
 extract_gstreamer_audio (const gchar *uri, TrackerSparqlBuilder *metadata)
 {
-	tracker_statement_list_insert (metadata, uri, 
-				       RDF_TYPE, 
-				       NMM_PREFIX "MusicPiece");
-
-	tracker_statement_list_insert (metadata, uri, 
-				       RDF_TYPE, 
-				       NFO_PREFIX "Audio");
-
 	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_AUDIO);
 }
 
 static void
 extract_gstreamer_video (const gchar *uri, TrackerSparqlBuilder *metadata)
 {
-	tracker_statement_list_insert (metadata, uri, 
-				       RDF_TYPE, 
-				       NMM_PREFIX "Video");
-
 	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_VIDEO);
 }
 
 static void
 extract_gstreamer_image (const gchar *uri, TrackerSparqlBuilder *metadata)
 {
-	tracker_statement_list_insert (metadata, uri, 
-				       RDF_TYPE, 
-				       NFO_PREFIX "Image");
-
 	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_IMAGE);
 }
 
+static void
+extract_gstreamer_3gpp (const gchar *uri, TrackerSparqlBuilder *metadata)
+{
+	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_3GPP);
+}
+
 TrackerExtractData *
 tracker_get_extract_data (void)
 {
