@@ -54,14 +54,14 @@
 #include "tracker-dbus.h"
 #include "tracker-extract.h"
 
-#define ABOUT								  \
+#define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
 
-#define LICENSE								  \
+#define LICENSE	  \
 	"This program is free software and comes without any warranty.\n" \
-	"It is licensed under version 2 or later of the General Public "  \
-	"License which can be viewed at:\n"				  \
-	"\n"								  \
+	"It is licensed under version 2 or later of the General Public " \
+	"License which can be viewed at:\n" \
+	"\n" \
 	"  http://www.gnu.org/licenses/gpl.txt\n"
 
 #define QUIT_TIMEOUT 30 /* 1/2 minutes worth of seconds */
@@ -70,10 +70,12 @@ static GMainLoop  *main_loop;
 static guint       quit_timeout_id = 0;
 
 static gboolean    version;
-static gboolean    disable_shutdown;
 static gint        verbosity = -1;
 static gchar      *filename;
 static gchar      *mime_type;
+static gboolean    disable_shutdown;
+static gboolean    force_internal_extractors;
+
 static TrackerFTSConfig *fts_config;
 
 static GOptionEntry  entries[] = {
@@ -100,7 +102,10 @@ static GOptionEntry  entries[] = {
 	  G_OPTION_ARG_NONE, &disable_shutdown,
 	  N_("Disable shutting down after 30 seconds of inactivity"),
 	  NULL },
-
+	{ "force-internal-extractors", 'i', 0,
+	  G_OPTION_ARG_NONE, &force_internal_extractors,
+	  N_("Force internal extractors over 3rd parties like libstreamanalyzer"),
+	  NULL },
 	{ NULL }
 };
 
@@ -108,7 +113,7 @@ static gboolean
 quit_timeout_cb (gpointer user_data)
 {
 	quit_timeout_id = 0;
-	
+
 	if (!disable_shutdown) {
 		g_main_loop_quit (main_loop);
 	} else {
@@ -125,9 +130,9 @@ tracker_main_quit_timeout_reset (void)
 		g_source_remove (quit_timeout_id);
 	}
 
-	quit_timeout_id = g_timeout_add_seconds (QUIT_TIMEOUT, 
-						 quit_timeout_cb, 
-						 NULL);
+	quit_timeout_id = g_timeout_add_seconds (QUIT_TIMEOUT,
+	                                         quit_timeout_cb,
+	                                         NULL);
 }
 
 static void
@@ -141,7 +146,7 @@ initialize_priority (void)
 	 * so complains if we do not check its returned value. But it
 	 * seems that since glibc 2.2.4, nice() can return -1 on a
 	 * successful call so we have to check value of errno too.
-	 * Stupid... 
+	 * Stupid...
 	 */
 	g_message ("Setting process priority");
 
@@ -149,7 +154,7 @@ initialize_priority (void)
 		const gchar *str = g_strerror (errno);
 
 		g_message ("Couldn't set nice value to 19, %s",
-			   str ? str : "no error given");
+		           str ? str : "no error given");
 	}
 }
 
@@ -161,12 +166,12 @@ initialize_directories (void)
 	/* NOTE: We don't create the database directories here, the
 	 * tracker-db-manager does that for us.
 	 */
-	
+
 	user_data_dir = g_build_filename (g_get_user_data_dir (),
-					  "tracker",
-					  NULL);
-	
-	g_message ("Checking directory exists:'%s'", user_data_dir);
+	                                  "tracker",
+	                                  NULL);
+
+	/* g_message ("Checking directory exists:'%s'", user_data_dir); */
 	g_mkdir_with_parents (user_data_dir, 00755);
 
 	g_free (user_data_dir);
@@ -196,8 +201,8 @@ signal_handler (int signo)
 		if (g_strsignal (signo)) {
 			g_print ("\n");
 			g_print ("Received signal:%d->'%s'\n",
-				 signo,
-				 g_strsignal (signo));
+			         signo,
+			         g_strsignal (signo));
 		}
 		break;
 	}
@@ -208,7 +213,7 @@ initialize_signal_handler (void)
 {
 #ifndef G_OS_WIN32
 	struct sigaction act;
-	sigset_t	 empty_mask;
+	sigset_t         empty_mask;
 
 	sigemptyset (&empty_mask);
 	act.sa_handler = signal_handler;
@@ -225,13 +230,11 @@ initialize_signal_handler (void)
 
 static void
 log_handler (const gchar    *domain,
-	     GLogLevelFlags  log_level,
-	     const gchar    *message,
-	     gpointer	     user_data)
+             GLogLevelFlags  log_level,
+             const gchar    *message,
+             gpointer        user_data)
 {
-	if (((log_level & G_LOG_LEVEL_DEBUG) && verbosity < 3) ||
-	    ((log_level & G_LOG_LEVEL_INFO) && verbosity < 2) ||
-	    ((log_level & G_LOG_LEVEL_MESSAGE) && verbosity < 1)) {
+	if (!tracker_log_should_handle (log_level, verbosity)) {
 		return;
 	}
 
@@ -252,7 +255,7 @@ log_handler (const gchar    *domain,
 		g_fprintf (stdout, "%s\n", message);
 		fflush (stdout);
 		break;
-	}	
+	}
 }
 
 TrackerFTSConfig *
@@ -265,47 +268,87 @@ tracker_main_get_fts_config (void)
 	return fts_config;
 }
 
+
+static int
+run_standalone (void)
+{
+	TrackerExtract *object;
+	GFile *file;
+	gchar *uri;
+	guint log_handler_id;
+
+	/* Set log handler for library messages */
+	log_handler_id = g_log_set_handler (NULL,
+	                                    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
+	                                    log_handler,
+	                                    NULL);
+
+	g_log_set_default_handler (log_handler, NULL);
+
+	/* Set the default verbosity if unset */
+	if (verbosity == -1) {
+		verbosity = 3;
+	}
+
+	tracker_albumart_init ();
+
+	/* This makes sure we don't steal all the system's resources */
+	initialize_priority ();
+
+	file = g_file_new_for_commandline_arg (filename);
+	uri = g_file_get_uri (file);
+
+	object = tracker_extract_new (disable_shutdown,
+	                              force_internal_extractors);
+
+	if (!object) {
+		g_free (uri);
+		return EXIT_FAILURE;
+	}
+
+	tracker_memory_setrlimits ();
+
+	tracker_extract_get_metadata_by_cmdline (object, uri, mime_type);
+
+	g_object_unref (object);
+	g_object_unref (file);
+	g_free (uri);
+
+	if (log_handler_id != 0) {
+		/* Unset log handler */
+		g_log_remove_handler (NULL, log_handler_id);
+	}
+
+	tracker_albumart_shutdown ();
+
+	return EXIT_SUCCESS;
+}
+
 int
 main (int argc, char *argv[])
 {
 	GOptionContext *context;
 	GError         *error = NULL;
 	TrackerConfig  *config;
+	TrackerExtract *object;
 	gchar          *log_filename = NULL;
-	gboolean        stand_alone = FALSE;
-	guint           log_handler_id = 0;
-
-	g_type_init ();
-
-	if (!g_thread_supported ()) {
-		g_thread_init (NULL);
-	}
-
-	dbus_g_thread_init ();
-
-	g_set_application_name ("tracker-extract");
-
-	setlocale (LC_ALL, "");
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/* Translators: this message will appear immediately after the	*/
-	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>	*/
+	/* Translators: this message will appear immediately after the  */
+	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>     */
 	context = g_option_context_new (_("- Extract file meta data"));
 
 	g_option_context_add_main_entries (context, entries, NULL);
 	g_option_context_parse (context, &argc, &argv, &error);
 
-	/* This makes sure we don't steal all the system's resources */
-	initialize_priority ();
-
 	if (!filename && mime_type) {
 		gchar *help;
 
 		g_printerr ("%s\n\n",
-			    _("Filename and mime type must be provided together"));
+		            _("Filename and mime type must be provided together"));
 
 		help = g_option_context_get_help (context, TRUE, NULL);
 		g_option_context_free (context);
@@ -323,53 +366,34 @@ main (int argc, char *argv[])
 	}
 
 	g_print ("Initializing tracker-extract...\n");
-	g_print ("  Shutdown after 30 seconds of inactivitiy is %s\n",
-		 disable_shutdown ? "disabled" : "enabled");
+
+	if (!filename) {
+		g_print ("  Shutdown after 30 seconds of inactivitiy is %s\n",
+		         disable_shutdown ? "disabled" : "enabled");
+	}
 
 	initialize_signal_handler ();
 
-	tracker_memory_setrlimits ();
+	g_type_init ();
+
+	if (!g_thread_supported ()) {
+		g_thread_init (NULL);
+	}
+
+	dbus_g_thread_init ();
+
+	g_set_application_name ("tracker-extract");
+
+	setlocale (LC_ALL, "");
 
 	/* Set conditions when we use stand alone settings */
-	stand_alone |= filename != NULL;
-
-	if (stand_alone) {
-		/* Set log handler for library messages */
-		log_handler_id = g_log_set_handler (NULL,
-						    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL,
-						    log_handler,
-						    NULL);
-		
-		g_log_set_default_handler (log_handler, NULL);
-
-		/* Set the default verbosity if unset */
-		if (verbosity == -1) {
-			verbosity = 3;
-		}
-	}
-
 	if (filename) {
-		TrackerExtract *extract;
-		GFile *file;
-		gchar *uri;
-
-		extract = tracker_extract_new (disable_shutdown);
-		if (!extract) {
-			return EXIT_FAILURE;
-		}
-
-		file = g_file_new_for_commandline_arg (filename);
-		uri = g_file_get_uri (file);
-
-		tracker_extract_get_metadata_by_cmdline (extract, uri, mime_type);
-
-		g_object_unref (extract);
-		g_object_unref (file);
-		g_free (uri);
-
-		goto done;
+		return run_standalone ();
 	}
 
+	/* Initialize subsystems */
+	initialize_directories ();
+
 	config = tracker_config_new ();
 
 	/* Extractor command line arguments */
@@ -377,25 +401,43 @@ main (int argc, char *argv[])
 		tracker_config_set_verbosity (config, verbosity);
 	}
 
-	if (!tracker_dbus_init ()) {
-		return EXIT_FAILURE;
-	}
-
-	/* Initialize subsystems */
-	initialize_directories ();
-
-	tracker_log_init (tracker_config_get_verbosity (config),
-			  &log_filename);
+	tracker_log_init (tracker_config_get_verbosity (config), &log_filename);
 	g_print ("Starting log:\n  File:'%s'\n", log_filename);
 	g_free (log_filename);
 
-	/* Make Tracker available for introspection */
-	if (!tracker_dbus_register_objects (disable_shutdown)) {
+	/* This makes sure we don't steal all the system's resources */
+	initialize_priority ();
+
+	if (!tracker_dbus_init ()) {
 		g_object_unref (config);
+		tracker_log_shutdown ();
 
 		return EXIT_FAILURE;
 	}
 
+	object = tracker_extract_new (disable_shutdown,
+	                              force_internal_extractors);
+
+	if (!object) {
+		g_object_unref (config);
+		tracker_log_shutdown ();
+
+		return EXIT_FAILURE;
+	}
+
+	tracker_memory_setrlimits ();
+
+	/* Make Tracker available for introspection */
+	if (!tracker_dbus_register_objects (object)) {
+		g_object_unref (object);
+		g_object_unref (config);
+		tracker_log_shutdown ();
+
+		return EXIT_FAILURE;
+	}
+
+	g_message ("Waiting for D-Bus requests...");
+
 	tracker_albumart_init ();
 
 	/* Main loop */
@@ -413,12 +455,5 @@ main (int argc, char *argv[])
 
 	g_object_unref (config);
 
-done:
-
-	if (log_handler_id != 0) {
-		/* Unset log handler */
-		g_log_remove_handler (NULL, log_handler_id);
-	}
-
 	return EXIT_SUCCESS;
 }
